{% extends 'admin/base.html' %}

{% load staticfiles %}

{% block extrahead %}
    <link rel="shortcut icon" href="{% static 'alerts/ulunq.ico' %}" />
{% endblock %}

{% block branding %}
<h1> Aurora admin </h1>

{% endblock%}
